export declare type State = Record<string, any>;
export declare type StateListener<T extends State, U = T> = (state: U) => void;
export declare type StateSelector<T extends State, U> = (state: T) => U;
export declare type PartialState<T extends State> = Partial<T> | ((state: T) => Partial<T>);
export declare type SetState<T extends State> = (partial: PartialState<T>) => void;
export declare type GetState<T extends State> = () => T;
export interface Subscribe<T> {
    (listener: StateListener<T>): () => void;
    <U>(selector: StateSelector<T, U>, listener: StateListener<T, U>): () => void;
}
export interface UseStore<T> {
    (): T;
    <U>(selector: StateSelector<T, U>, dependencies?: ReadonlyArray<any>): U;
}
export interface StoreApi<T> {
    getState: GetState<T>;
    setState: SetState<T>;
    subscribe: Subscribe<T>;
    destroy: () => void;
}
export default function create<TState extends State>(createState: (set: SetState<State>, get: GetState<State>, api: any) => TState): [UseStore<TState>, StoreApi<TState>];
